@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -30,6 +30,7 @@ from pathlib import Path
 from typing import Optional, Union
 
 import paramiko
+import paramiko.ssh_exception
 from lxml import etree
 
 from gvm.errors import GvmError
@@ -298,6 +299,7 @@ class SSHConnection(GvmConnection):
         """Get the remote host key for ssh connection"""
         try:
             tmp_socket = socketlib.socket()
+            tmp_socket.settimeout(self._timeout)
             tmp_socket.connect((self.hostname, self.port))
         except OSError as e:
             raise GvmError(
@@ -380,6 +382,7 @@ class SSHConnection(GvmConnection):
             paramiko.BadHostKeyException,
             paramiko.AuthenticationException,
             paramiko.SSHException,
+            paramiko.ssh_exception.NoValidConnectionsError,
             ConnectionError,
         ) as e:
             raise GvmError(f"SSH Connection failed: {e}") from None
